Learn R Programming

fullfact (version 1.0)

resampFamily: Bootstrap resample within families

Description

Bootstrap resample observations grouped by family identities for a specified number of iterations to create a resampled data set.

Usage

resampFamily(dat, copy, family, iter)

Arguments

dat
Data frame observed data to resample.
copy
Column numbers to copy.
family
Column name containing family identity information.
iter
Number of iterations for resampling.

Value

Because of the large file sizes that can be produced, the resampling of each family X is saved separately as a common separated (X_resampF.csv) file in the working directory. These files are merged to create the final resampled data set (resamp_datF.csv).

Details

The resampled data can be used for producing bootstrap confidence intervals.

See Also

resampRepli

Examples

Run this code
data(chinook_length) #Chinook salmon offspring length
#resampFamily(dat=chinook_length,copy=c(3:8),family="family",iter=1000)
resampFamily(dat=chinook_length,copy=c(3:8),family="family",iter=2)
#example with a couple iterations

Run the code above in your browser using DataLab