Learn R Programming

fullfact (version 1.0)

resampGlmer3: Bootstrap components for non-normal data 3

Description

Extracts additive genetic, non-additive genetic, and maternal variance components from a generalized linear mixed-effect model using the glmer function of the lme4 package. Model random effects are dam, sire, dam by sire, and any additional fixed and/or random effects.

Usage

resampGlmer3(resamp, dam, sire, response, fam_link, start, end, remain, quasi = F)

Arguments

resamp
Data frame of bootstrap resampled data.
dam
Column name containing dam(female) parent identity information.
sire
Column name containing sire(male) parent identity information.
response
Column name containing the offspring (response) phenotype values.
fam_link
The family and link in family(link) format. Supported options are binomial(logit), binomial(probit), poisson(log), and poisson (sqrt).
start
Starting model number.
end
Ending model number.
remain
Remaining formula using lme4 package format with # sign (see column names), e.g. fixed# + (1|random#).
quasi
Incorporate overdispersion or quasi-error structure.

Value

A data frame with columns containing the raw variance components for dam, sire, dam by sire, residual, total, additive genetic, non-additive genetic, and maternal. Also columns containing the raw variance components for remaining formula components. The number of rows in the data frame matches the number of iterations in the resampled data set and each row represents a model number.

Details

Used for bootstrap resampled data set produced using resampRepli or resampFamily. Laplace approximation parameter estimation is used, which is a true likelihood method (Bolker et al. 2009). For the overdispersion option, an observation-level random effect is added to the model (Atkins et al. 2013). Extracts the dam, sire, dam, and dam by sire variance components. Extracts any additional fixed effect and random effect variance components. The fixed-effect variance component is as a single group using the method described by Nakagawa and Schielzeth (2013). The residual variance component for the fam_links are described by Nakagawa and Schielzeth (2010, 2013). Calculates the total variance component. Calculates the additive genetic, non-additive genetic, and maternal variance components (see Lynch and Walsh 1998, p. 603).

References

Atkins DC, Baldwin SA, Zheng C, Gallop RJ, Neighbors C. 2013. A tutorial on count regression and zero-altered count models for longitudinal substance use data. Psychology of Addictive Behaviors 27(1): 166-177. DOI: 10.1037/a0029508

Bolker BM, Brooks ME, Clark CJ, Geange SW, Poulsen JR, Stevens MHH, White J-SS. 2009. Generalized linear mixed models: a practical guide for ecology and evolution. Trends in Ecology and Evolution 24(3): 127-135. DOI: 10.1016/j.tree.2008.10.008

Lynch M, Walsh B. 1998. Genetics and Analysis of Quantitative Traits. Sinauer Associates, Massachusetts.

Nakagawa S, Schielzeth H. 2010. Repeatability for Gaussian and non-Gaussian data: a practical guide for biologists. Biological Reviews 85(4): 935-956. DOI: 10.1111/j.1469-185X.2010.00141.x

Nakagawa S, Schielzeth H. 2013. A general and simple method for obtaining R2 from generalized linear mixed-effects models. Methods in Ecology and Evolution 4(2): 133-142. DOI: 10.1111/j.2041-210x.2012.00261.x

See Also

resampGlmer, resampGlmer2

Examples

Run this code
data(chinook_resampS) #5 iterations

## Not run: survival_rcomp3<- resampGlmer3(resamp=survival_datR,dam="dam",sire="sire",
# response="status",fam_link=binomial(logit),start=1,end=1000,
# remain="egg_size# + (1|tray#)")## End(Not run)

Run the code above in your browser using DataLab